// java wrapper for vtkCompositeTransferFunctionItem object
//

package vtk;
import vtk.*;

public class vtkCompositeTransferFunctionItem extends vtkColorTransferFunctionItem
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetOpacityFunction_2(vtkPiecewiseFunction id0);
  public void SetOpacityFunction(vtkPiecewiseFunction id0)
    { SetOpacityFunction_2(id0); }

  private native long GetOpacityFunction_3();
  public vtkPiecewiseFunction GetOpacityFunction() {
    long temp = GetOpacityFunction_3();

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkCompositeTransferFunctionItem() { super(); }

  public vtkCompositeTransferFunctionItem(long id) { super(id); }
  public native long   VTKInit();

}
